creator
library
Classes
AsyncData <T >
AsyncData is either in waiting state, or in active state with data.
Change <T >
Change wraps current state and previous state.
Creator <T >
Creator creates a stream of T. It is able to return a valid state when
firstly being watched.
CreatorBase <T >
Base class of creators. Creators describe the graph dependencies.
Also see ElementBase . Note that T should be immutable data.
CreatorElement <T >
Creator's element.
CreatorGraph
CreatorGraph holds a Ref, which holds the graph internally. Flutter app
should be wrapped with this. By default it uses DefaultCreatorObserver to
log state changes.
CreatorGraphData
The inherit widget for CreatorGraph.
CreatorObserver
Observer can listen to creator state changes.
DefaultCreatorObserver
Default observer which just log the new states and error.
ElementBase <T >
Base class of elements. Element holds the actual state. Creator and element
always exist as a pair in the graph.
Emitter <T >
Emitter creates a stream of Future
EmitterElement <T >
Emitter's element.
Ref
Ref holds the creator graph data, including states and dependencies.
Watcher
Watch creators to build a widget or to perform other action.